==> datapark-facade-3.0.14-sources.jar: com/bxm/datapark/web/model/SspActivityData.java <==
package com.bxm.datapark.web.model;

import java.io.Serializable;

/**
 * <p>
 * SSP场景DSP活动报表
 * </p>
 *
 * @author zhengwangeng
 * @since 2020-08-13
 */
public class SspActivityData implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 活动ID
     */
    private Long activityId;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动首页pv
     */
    private Integer indexPv;

    /**
     * 活动首页uv
     */
    private Integer indexUv;

    /**
     * 活动参与率
     */
    private Double joinRate;

    /**
     * 每uv播放
     */
    private Double uvPlay;

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Integer getIndexPv() {
        return indexPv;
    }

    public void setIndexPv(Integer indexPv) {
        this.indexPv = indexPv;
    }

    public Integer getIndexUv() {
        return indexUv;
    }

    public void setIndexUv(Integer indexUv) {
        this.indexUv = indexUv;
    }

    public Double getJoinRate() {
        return joinRate;
    }

    public void setJoinRate(Double joinRate) {
        this.joinRate = joinRate;
    }

    public Double getUvPlay() {
        return uvPlay;
    }

    public void setUvPlay(Double uvPlay) {
        this.uvPlay = uvPlay;
    }
}

==> datapark-facade-3.1.17-sources.jar: com/bxm/datapark/web/model/SspActivityData.java <==
package com.bxm.datapark.web.model;

import java.io.Serializable;

/**
 * <p>
 * SSP场景DSP活动报表
 * </p>
 *
 * @author zhengwangeng
 * @since 2020-08-13
 */
public class SspActivityData implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 活动ID
     */
    private Long activityId;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动首页pv
     */
    private Integer indexPv;

    /**
     * 曝光pv
     */
    private Integer exposurePv;

    /**
     * 活动首页uv
     */
    private Integer indexUv;

    /**
     * 活动参与率
     */
    private Double joinRate;

    /**
     * 每uv播放
     */
    private Double uvPlay;

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Integer getIndexPv() {
        return indexPv;
    }

    public void setIndexPv(Integer indexPv) {
        this.indexPv = indexPv;
    }

    public Integer getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Integer exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Integer getIndexUv() {
        return indexUv;
    }

    public void setIndexUv(Integer indexUv) {
        this.indexUv = indexUv;
    }

    public Double getJoinRate() {
        return joinRate;
    }

    public void setJoinRate(Double joinRate) {
        this.joinRate = joinRate;
    }

    public Double getUvPlay() {
        return uvPlay;
    }

    public void setUvPlay(Double uvPlay) {
        this.uvPlay = uvPlay;
    }
}
